@@ -63,12 +63,10 @@ var IndicatorType = {
 };
 
 
-var IndicatorMenu = new Lang.Class({
-    Name: 'PomodoroIndicatorMenu',
-    Extends: PopupMenu.PopupMenu,
+var IndicatorMenu = class extends PopupMenu.PopupMenu {
 
-    _init(indicator) {
-        this.parent(indicator.actor, St.Align.START, St.Side.TOP);
+    constructor(indicator) {
+        super(indicator.actor, St.Align.START, St.Side.TOP);
 
         this._isPaused = null;
         this._timerState = null;
@@ -81,7 +79,7 @@ var IndicatorMenu = new Lang.Class({
         this.indicator = indicator;
 
         this._populate();
-    },
+    }
 
     _createActionButton(iconName, accessibleName) {
         let button = new St.Button({ reactive: true,
@@ -91,7 +89,7 @@ var IndicatorMenu = new Lang.Class({
                                      style_class: 'system-menu-action extension-pomodoro-indicator-menu-action' });
         button.child = new St.Icon({ icon_name: iconName });
         return button;
-    },
+    }
 
     _onTimerClicked() {
         this.close();
@@ -100,19 +98,19 @@ var IndicatorMenu = new Lang.Class({
             Extension.extension.dialog.open(true);
             Extension.extension.dialog.pushModal();
         }
-    },
+    }
 
     _onStartClicked() {
         this.indicator.timer.start();
 
         this.close();
-    },
+    }
 
     _onStopClicked() {
         this.indicator.timer.stop();
 
         this.close();
-    },
+    }
 
     _onPauseClicked() {
         if (!this.indicator.timer.isPaused ()) {
@@ -123,7 +121,7 @@ var IndicatorMenu = new Lang.Class({
 
             this.close();
         }
-    },
+    }
 
     _populate() {
         let toggleItem = new PopupMenu.PopupMenuItem(_("Pomodoro Timer"),
@@ -182,7 +180,7 @@ var IndicatorMenu = new Lang.Class({
         this.addAction(_("Preferences"), this._activatePreferences.bind(this));
         this.addAction(_("Stats"), this._activateStats.bind(this));
         this.addAction(_("Quit"), this._activateQuit.bind(this));
-    },
+    }
 
     addStateMenuItem(name, label) {
         if (!this._stateItems) {
@@ -198,7 +196,7 @@ var IndicatorMenu = new Lang.Class({
         this._stateItems[name] = menuItem;
 
         return menuItem;
-    },
+    }
 
     _onActorMapped(actor) {
         if (actor.mapped && this._timerUpdateId == 0) {
@@ -210,7 +208,7 @@ var IndicatorMenu = new Lang.Class({
             this.indicator.timer.disconnect(this._timerUpdateId);
             this._timerUpdateId = 0;
         }
-    },
+    }
 
     _onTimerUpdate() {
         let timer = this.indicator.timer;
@@ -253,7 +251,7 @@ var IndicatorMenu = new Lang.Class({
         }
 
         this.timerLabel.set_text(this._formatTime(remaining));
-    },
+    }
 
     _formatTime(remaining) {
         if (remaining < 0.0) {
@@ -264,27 +262,27 @@ var IndicatorMenu = new Lang.Class({
         let seconds = Math.floor(remaining % 60);
 
         return '%02d:%02d'.format(minutes, seconds);
-    },
+    }
 
     _activateStats() {
         let timestamp = global.get_current_time();
 
         this.indicator.timer.showMainWindow('stats', timestamp);
-    },
+    }
 
     _activatePreferences() {
         let timestamp = global.get_current_time();
 
         this.indicator.timer.showPreferences(timestamp);
-    },
+    }
 
     _activateQuit() {
         this.indicator.timer.quit();
-    },
+    }
 
     _activateState(stateName) {
         this.indicator.timer.setState(stateName);
-    },
+    }
 
     destroy() {
         if (this._timerUpdateId) {
@@ -299,15 +297,17 @@ var IndicatorMenu = new Lang.Class({
 
         this.indicator = null;
 
-        this.parent();
+        super.destroy();
     }
-});
+};
 
 
-var TextIndicator = new Lang.Class({
-    Name: 'PomodoroTextIndicator',
+var TextIndicator = GObject.registerClass(
+class PomodoroTextIndicator extends GObject.Object {
 
     _init(timer) {
+        super._init();
+
         this._initialized     = false;
         this._state           = Timer.State.NULL;
         this._minHPadding     = 0;
@@ -318,7 +318,7 @@ var TextIndicator = new Lang.Class({
 
         this.timer = timer;
 
-        this.actor = new Shell.GenericContainer({ reactive: true });
+        this.actor = new St.Widget({ reactive: true });
         this.actor._delegate = this;
 
         this.label = new St.Label({ style_class: 'system-status-label',
@@ -335,9 +335,6 @@ var TextIndicator = new Lang.Class({
             });
         this.actor.add_child(this.label);
 
-        this.actor.connect('get-preferred-width', this._getPreferredWidth.bind(this));
-        this.actor.connect('get-preferred-height', this._getPreferredHeight.bind(this));
-        this.actor.connect('allocate', this._allocate.bind(this));
         this.actor.connect('style-changed', this._onStyleChanged.bind(this));
         this.actor.connect('destroy', this._onActorDestroy.bind(this));
 
@@ -354,7 +351,7 @@ var TextIndicator = new Lang.Class({
         else {
             this.actor.set_opacity(FADE_OUT_OPACITY * 255);
         }
-    },
+    }
 
     _onStyleChanged(actor) {
         let themeNode = actor.get_theme_node();
@@ -366,46 +363,12 @@ var TextIndicator = new Lang.Class({
         this._natHPadding = themeNode.get_length('-natural-hpadding');
         this._digitWidth  = metrics.get_approximate_digit_width() / Pango.SCALE;
         this._charWidth   = metrics.get_approximate_char_width() / Pango.SCALE;
-    },
+    }
 
     _getWidth() {
         return Math.ceil(4 * this._digitWidth + 0.5 * this._charWidth);
-    },
+    }
 
-    _getPreferredWidth(actor, forHeight, alloc) {
-        let child        = actor.get_first_child();
-        let minWidth     = this._getWidth();
-        let naturalWidth = minWidth;
-
-        minWidth     += 2 * this._minHPadding;
-        naturalWidth += 2 * this._natHPadding;
-
-        if (child) {
-            [alloc.min_size, alloc.natural_size] = child.get_preferred_width(-1);
-        }
-        else {
-            alloc.min_size = alloc.natural_size = 0;
-        }
-
-        if (alloc.min_size < minWidth) {
-            alloc.min_size = minWidth;
-        }
-
-        if (alloc.natural_size < naturalWidth) {
-            alloc.natural_size = naturalWidth;
-        }
-    },
-
-    _getPreferredHeight(actor, forWidth, alloc) {
-        let child = actor.get_first_child();
-
-        if (child) {
-            [alloc.min_size, alloc.natural_size] = child.get_preferred_height(-1);
-        }
-        else {
-            alloc.min_size = alloc.natural_size = 0;
-        }
-    },
 
     _getText(state, remaining) {
         if (remaining < 0.0) {
@@ -416,7 +379,7 @@ var TextIndicator = new Lang.Class({
         let seconds = Math.floor(remaining % 60);
 
         return '%02d:%02d'.format(minutes, seconds);
-    },
+    }
 
     _onTimerUpdate() {
         let state = this.timer.getState();
@@ -440,33 +403,8 @@ var TextIndicator = new Lang.Class({
         }
 
         this.label.set_text(this._getText(state, remaining));
-    },
+    }
 
-    _allocate(actor, box, flags) {
-        let child = actor.get_first_child();
-        if (!child)
-            return;
-
-        let [minWidth, natWidth] = child.get_preferred_width(-1);
-
-        let availWidth  = box.x2 - box.x1;
-        let availHeight = box.y2 - box.y1;
-
-        let childBox = new Clutter.ActorBox();
-        childBox.y1 = 0;
-        childBox.y2 = availHeight;
-
-        if (natWidth + 2 * this._natHPadding <= availWidth) {
-            childBox.x1 = this._natHPadding;
-            childBox.x2 = availWidth - this._natHPadding;
-        }
-        else {
-            childBox.x1 = this._minHPadding;
-            childBox.x2 = availWidth - this._minHPadding;
-        }
-
-        child.allocate(childBox, flags);
-    },
 
     _onActorDestroy() {
         if (this._onTimerUpdateId) {
@@ -477,7 +415,7 @@ var TextIndicator = new Lang.Class({
         this.actor._delegate = null;
 
         this.emit('destroy');
-    },
+    }
 
     destroy() {
         this.actor.destroy();
@@ -486,20 +424,19 @@ var TextIndicator = new Lang.Class({
 Signals.addSignalMethods(TextIndicator.prototype);
 
 
-var ShortTextIndicator = new Lang.Class({
-    Name: 'PomodoroShortTextIndicator',
-    Extends: TextIndicator,
+var ShortTextIndicator = GObject.registerClass(
+class PomodoroShortTextIndicator extends TextIndicator {
 
     _init(timer) {
-        this.parent(timer);
+        super._init(timer);
 
         this.label.set_x_align(Clutter.ActorAlign.END);
-    },
+    }
 
     _getWidth() {
         return Math.ceil(2 * this._digitWidth +
                          1 * this._charWidth);
-    },
+    }
 
     _getText(state, remaining) {
         if (remaining < 0.0) {
@@ -519,11 +456,12 @@ var ShortTextIndicator = new Lang.Class({
     }
 });
 
-
-var IconIndicator = new Lang.Class({
-    Name: 'PomodoroIconIndicator',
+var IconIndicator = GObject.registerClass(
+class PomodoroIconIndicator extends GObject.Object {
 
     _init(timer) {
+        super._init();
+
         this._state           = Timer.State.NULL;
         this._progress        = 0.0;
         this._minHPadding     = 0;
@@ -536,7 +474,7 @@ var IconIndicator = new Lang.Class({
 
         this.timer = timer;
 
-        this.actor = new Shell.GenericContainer({ reactive: true });
+        this.actor = new St.Widget({ reactive: true });
         this.actor._delegate = this;
 
         this.icon = new St.DrawingArea({ style_class: 'system-status-icon' });
@@ -545,9 +483,6 @@ var IconIndicator = new Lang.Class({
         this.icon.connect('destroy', this._onIconDestroy.bind(this));
         this.actor.add_child(this.icon);
 
-        this.actor.connect('get-preferred-width', this._getPreferredWidth.bind(this));
-        this.actor.connect('get-preferred-height', this._getPreferredHeight.bind(this));
-        this.actor.connect('allocate', this._allocate.bind(this));
         this.actor.connect('style-changed', this._onStyleChanged.bind(this));
         this.actor.connect('destroy', this._onActorDestroy.bind(this));
 
@@ -556,7 +491,7 @@ var IconIndicator = new Lang.Class({
         this._onTimerUpdate();
 
         this._state = this.timer.getState();
-    },
+    }
 
     _onIconStyleChanged(actor) {
         let themeNode = actor.get_theme_node();
@@ -566,7 +501,7 @@ var IconIndicator = new Lang.Class({
         [actor.min_height, actor.natural_height] = themeNode.adjust_preferred_height(size, size);
 
         this._iconSize = size;
-    },
+    }
 
     _onIconRepaint(area) {
         let cr = area.get_context();
@@ -612,14 +547,14 @@ var IconIndicator = new Lang.Class({
         }
 
         cr.$dispose();
-    },
+    }
 
     _onIconDestroy() {
         if (this._timerUpdateId) {
             this.timer.disconnect(this._timerUpdateId);
             this._timerUpdateId = 0;
         }
-    },
+    }
 
     _onStyleChanged(actor) {
         let themeNode = actor.get_theme_node();
@@ -629,7 +564,7 @@ var IconIndicator = new Lang.Class({
         this._minVPadding = themeNode.get_length('-minimum-vpadding');
         this._natVPadding = themeNode.get_length('-natural-vpadding');
 
-        let color = themeNode.get_foreground_color()
+        let color = themeNode.get_foreground_color();
         this._primaryColor = color;
         this._secondaryColor = new Clutter.Color({
             red: color.red,
@@ -637,35 +572,8 @@ var IconIndicator = new Lang.Class({
             blue: color.blue,
             alpha: color.alpha * FADE_OUT_OPACITY
         });
-    },
+    }
 
-    _getPreferredWidth(actor, forHeight, alloc) {
-        let child = actor.get_first_child();
-
-        if (child) {
-            [alloc.min_size, alloc.natural_size] = child.get_preferred_width(-1);
-        }
-        else {
-            alloc.min_size = alloc.natural_size = 0;
-        }
-
-        alloc.min_size += 2 * this._minHPadding;
-        alloc.natural_size += 2 * this._natHPadding;
-    },
-
-    _getPreferredHeight(actor, forWidth, alloc) {
-        let child = actor.get_first_child();
-
-        if (child) {
-            [alloc.min_size, alloc.natural_size] = child.get_preferred_height(-1);
-        }
-        else {
-            alloc.min_size = alloc.natural_size = 0;
-        }
-
-        alloc.min_size += 2 * this._minVPadding;
-        alloc.natural_size += 2 * this._natVPadding;
-    },
 
     _onTimerUpdate() {
         let state = this.timer.getState();
@@ -676,34 +584,8 @@ var IconIndicator = new Lang.Class({
             this._progress = progress;
             this.icon.queue_repaint();
         }
-    },
+    }
 
-    _allocate(actor, box, flags) {
-        let child = actor.get_first_child();
-        if (!child) {
-            return;
-        }
-
-        let availWidth  = box.x2 - box.x1;
-        let availHeight = box.y2 - box.y1;
-
-        let [minWidth, natWidth] = child.get_preferred_width(availHeight);
-
-        let childBox = new Clutter.ActorBox();
-        childBox.y1 = 0;
-        childBox.y2 = availHeight;
-
-        if (natWidth + 2 * this._natHPadding <= availWidth) {
-            childBox.x1 = this._natHPadding;
-            childBox.x2 = availWidth - this._natHPadding;
-        }
-        else {
-            childBox.x1 = this._minHPadding;
-            childBox.x2 = availWidth - this._minHPadding;
-        }
-
-        child.allocate(childBox, flags);
-    },
 
     _onActorDestroy() {
         if (this._timerUpdateId) {
@@ -717,7 +599,7 @@ var IconIndicator = new Lang.Class({
         this.actor._delegate = null;
 
         this.emit('destroy');
-    },
+    }
 
     destroy() {
         this.actor.destroy();
@@ -726,12 +608,11 @@ var IconIndicator = new Lang.Class({
 Signals.addSignalMethods(IconIndicator.prototype);
 
 
-var Indicator = new Lang.Class({
-    Name: 'PomodoroIndicator',
-    Extends: PanelMenu.Button,
+var Indicator = GObject.registerClass(
+class PomodoroIndicator extends PanelMenu.Button {
 
     _init(timer, type) {
-        this.parent(St.Align.START, _("Pomodoro"), true);
+        super._init(St.Align.START, _("Pomodoro"), true);
 
         this.timer  = timer;
         this.widget = null;
@@ -745,6 +626,7 @@ var Indicator = new Lang.Class({
 
         this._hbox = new St.BoxLayout({ style_class: 'panel-status-menu-box' });
         this._hbox.pack_start = true;
+        this._hbox.set_y_align(Clutter.ActorAlign.CENTER);
         this._hbox.add_child(this._arrow);
         this.actor.add_child(this._hbox);
 
@@ -755,7 +637,7 @@ var Indicator = new Lang.Class({
 
         this._timerPausedId = this.timer.connect('paused', this._onTimerPaused.bind(this));
         this._timerResumedId = this.timer.connect('resumed', this._onTimerResumed.bind(this));
-    },
+    }
 
     setType(type) {
         if (this.widget) {
@@ -783,7 +665,7 @@ var Indicator = new Lang.Class({
                                         GObject.BindingFlags.SYNC_CREATE);
 
         this._hbox.add_child(this.widget.actor);
-    },
+    }
 
     _onBlinked() {
         this._blinking = false;
@@ -791,7 +673,7 @@ var Indicator = new Lang.Class({
         if (this.timer.isPaused()) {
             this._blink();
         }
-    },
+    }
 
     _blink() {
         if (!this._blinking) {
@@ -837,11 +719,11 @@ var Indicator = new Lang.Class({
                     });
             }
         }
-    },
+    }
 
     _onTimerPaused() {
         this._blink();
-    },
+    }
 
     _onTimerResumed() {
         if (this._blinking) {
@@ -865,7 +747,7 @@ var Indicator = new Lang.Class({
                 this._blinkTimeoutSource = 0;
             }
         }
-    },
+    }
 
     _onActorDestroy() {
         Tweener.removeTweens(this._hbox);
@@ -885,9 +767,9 @@ var Indicator = new Lang.Class({
             this.icon.destroy();
             this.icon = null;
         }
-    },
+    }
 
     destroy() {
-        this.parent();
+        super.destroy();
     }
 });
